@@ -408,8 +408,8 @@ seas <- function(x, xreg = NULL, xtrans = NULL,
     stop("no output has been generated")
   }
 
-  # add all series that have been produced and are specified in SERIES_SUFFIX
-  file.suffix <- unlist(lapply(strsplit(flist, "\\."), function(x) x[[2]]))
+  # add all series that have been produced and are specified in SERIES_SUFFIX  
+  file.suffix <- unlist(lapply(strsplit(flist, "\\."), function(x) x[[length(x)]]))
   is.series <- file.suffix %in% SERIES_SUFFIX
 
   series.list <- lapply(file.path(wdir, flist[is.series]), read_series, 
@@ -452,7 +452,22 @@ seas <- function(x, xreg = NULL, xtrans = NULL,
   z$est <- read_est(iofile)
 
   # read .mdl file
-  z$model <- try(parse_spc(readLines(paste0(iofile, ".mdl"))), silent = TRUE) 
+
+  mdl <- readLines(paste0(iofile, ".mdl"))
+
+  # Workaround: in the .mdl output, full regime changes are returned weiredly. 
+  # E.g.
+  # variables=(
+  #  td/ for before 1955.Jan/
+  # )
+  is.r.change <- grepl("//?[ A-Za-z]", mdl)
+  rch0 <- mdl[is.r.change]  
+  rch <- gsub("//[ A-Za-z].+ ", "//", rch0)
+  rch <- gsub("/[ A-Za-z].+ ", "/", rch0)
+  mdl[is.r.change] <- rch
+  z$model <- try(parse_spc(mdl), silent = TRUE) 
+
+  is.r.change <- grepl("//?[ A-Za-z]", mdl)
 
   # fails for very complicated models, but is needed only for static()
   if (inherits(z$model, "try-error")){
@@ -569,6 +584,7 @@ run_x13 <- function(file, out){
   # error message on non-zero failing
   if (!is.null(attr(msg, "status"))){
     if (attr(msg, "status") > 0){
+      msg <- system(paste(x13.bin, file, flags), intern = TRUE, ignore.stderr = FALSE)
       stop("X-13 has returned a non-zero exist status, which means that the current spec file cannot be processed for an unknown reason.", call. = FALSE)
     }
   }
